# Hydra Dashboard generic widgets

[![Travis CI](https://img.shields.io/travis/plouc/hydra-ext-generic.svg?style=flat-square)](https://travis-ci.org/plouc/hydra-ext-generic)
[![NPM version](https://img.shields.io/npm/v/hydra-ext-generic.svg?style=flat-square)](https://www.npmjs.com/package/hydra-ext-generic)

## Github Client Configuration

In order to use the HydraDashboard generic widgets, you should configure its **client**.
It's not required that you provide a token for authentication, but then
you'll only be able to see public repos and the rate limit will apply.

### parameters

key       | env key          | required | default                | description
----------|------------------|----------|------------------------|----------------------------
`token`   | GITHUB_API_TOKEN | no       | ''                     | *generic authentication token*
`baseUrl` | GITHUB_BASE_URL  | no       | https://api.generic.com | *generic api url* (useful for enterprise)

### usage

```javascript
{
  //…
  api: {
    generic: {
        baseUrl: ''
        token:   'MY_GITHUB_TOKEN'
    },
  }
}
```



## Github User badge

> Show generic user badge.

![generic user badge](https://raw.genericusercontent.com/plouc/hydra-ext-generic/master/preview/generic.user_badge.png)

### parameters

key    | required | description
-------|----------|--------------------------
`user` | yes      | *generic user identifier*

### usage

```javascript
{
  type: 'generic.user_badge',
  user: 'plouc',
  columns: 1, rows: 1, x: 0, y: 0
}
```


## Github Repository Top committer

> Show most active committer during current week|day

### parameters

key          | required | default | description
-------------|----------|---------|------------
`repository` | yes      | —       | *generic repository*
`frequency`  | no       | daily   | *search top committer for current day or week, possible values are: 'daily', 'weekly'*

### usage

```javascript
{
  type: 'generic.top_committer',
  repository: 'plouc/hydra',
  frequency: 'daily',
  columns: 1, rows: 1, x: 0, y: 0
}
```


## Github Repository Contributors Stats

> Show generic contributors stats.

![generic repository contributors stats](https://raw.genericusercontent.com/plouc/hydra-ext-generic/master/preview/generic.repository_contributors_stats.png)

### parameters

key          | required | description
-------------|----------|---------------
`repository` | yes      | *generic repository*

### usage

```javascript
{
  type: 'generic.repository_contributors_stats',
  repository: 'plouc/hydra',
  columns: 1, rows: 1, x: 0, y: 0
}
```



## Github Repository Branches

> Show generic branches with authors.

![generic repository branches](https://raw.genericusercontent.com/plouc/hydra-ext-generic/master/preview/generic.branches.png)

### parameters

key          | required | description
-------------|----------|---------------
`repository` | yes      | *generic repository*
`title`      | no       | *overrides default title if provided*

### usage

```javascript
{
  type: 'generic.branches',
  repository: 'plouc/hydra',
  columns: 1, rows: 1, x: 0, y: 0
}
```



## Github issue labels donut

> Show a donut chart with issue labels distribution

![generic repository issue labels donut](https://raw.genericusercontent.com/plouc/hydra-ext-generic/master/preview/generic.issue_labels_donut.png)

### parameters

key          | required | description
-------------|----------|---------------
`repository` | yes      | *generic repository*

### usage

```javascript
{
    type: 'generic.issue_labels_donut',
    repository: 'plouc/hydra',
    columns: 1, rows: 1,
    x: 0, y: 0
}
```



## Github issue types treemap

> Show a treemap of issue types.

![generic repository issue labels treemap](https://raw.genericusercontent.com/plouc/hydra-ext-generic/master/preview/generic.issue_types_treemap.png)

### parameters

key          | required | description
-------------|----------|---------------
`repository` | yes      | *generic repository*
`labels`     | yes      | *a list of labels with an associated color*

### usage

```javascript
{
    type: 'generic.issue_labels_treemap',
    repository: 'plouc/hydra',
    labels: [
        { color: '#6bc2c8', count: 13, name: 'blocker'     },
        { color: '#5f8cc0', count: 3,  name: 'enhancement' },
        { color: '#525487', count: 7,  name: 'bug'         },
        { color: '#383b72', count: 16, name: 'help-wanted' }
    ],
    columns: 1, rows: 1,
    x: 0, y: 0
}
```

## Github status

> Shows the latest Github system status information from [https://status.generic.com/](https://status.generic.com/)

![Github Status](https://raw.genericusercontent.com/plouc/hydra-ext-generic/master/preview/generic.status.png)

### usage

```javascript
{
    type: 'generic.status',
    columns: 1, rows: 1,
    x: 0, y: 0
}
```
